#!/bin/bash 

function get_existing_databases(){
  list_db_output=$(su - $instance_owner -c "export LANG=en_US; db2 list db directory");
  if [ $? -eq 4 ];then
    return 0 # most often no database cataloged
  fi
  export IFS="
"
  local dbalias=""
  
  for line in $list_db_output;do
    if echo $line | grep -E "Database name[[:space:]]+=" >/dev/null; then
      dbname="${line#*= }"
      if [ "${dbname#TPC_}" != "${dbname}" ];then
        dbname_used="$dbname_used\n${line#*= }"
      fi
    elif echo $line | grep -E "Database alias[[:space:]]+=" >/dev/null; then
      dbalias=${line#*= }
      if [ "${dbalias#TPC_}" != "${dbalias}" ];then
        dbname_used="$dbname_used\n${line#*= }"
      fi
    elif echo $line | grep -E "Local database directory[[:space:]]+=" > /dev/null; then
      #create a variable with latest database alias
      export $dbalias=xxx
    fi
  done
  unset IFS
  dbname_used=$(echo -e $dbname_used | sort | uniq)
}

function get_mdm_databases(){
  DIRECTOR_PATH=$(rpm -q --queryformat "%{INSTPREFIXES}"  ITDServer)
  MDM_Properties=${DIRECTOR_PATH}/classes/mdm/dm/config/MDM.properties
  if [ -e ${MDM_Properties} ];then
    if [ "$PROD_NAME" == "DM" ]; then
      tmp_mdm_databases=$(awk '/[Mm][Dd][Mm]\.[dD][bB][nN][aA][mM][eE]=/ {print $2}' FS="=" $MDM_Properties)
    elif [ "$PROD_NAME" == "PM" ]; then
      tmp_mdm_databases=$(awk '/[Mm][Dd][Mm]\.[Pp][Mm]\.[dD][bB][nN][aA][mM][eE]=/ {print $2}' FS="=" $MDM_Properties)
    elif [ "$PROD_NAME" == "RM" ]; then
      tmp_mdm_databases=$(awk '/[Mm][Dd][Mm]\.[Rr][Mm]\..*\.[dD][bB][nN][aA][mM][eE]=/ {print $2}' FS="=" $MDM_Properties)
    fi
    tmp_mdm_databases=$(echo $tmp_mdm_databases | tr a-z A-Z)
    for tmp_db in $tmp_mdm_databases; do
      if [ "${mdm_databases/$tmp_db/}" == "${mdm_databases}" ];then
        mdm_databases="$mdm_databases $tmp_db"
      fi
    done
  fi
}

function catalog_node(){
  svcename=$(su - $instance_owner -c "export LANG=en_US; db2 get dbm cfg | grep SVCENAME")
  svcename=${svcename#*= }
  if [ -z "$svcename" ]; then
    exit 40
  fi 
  list_nodes_output=$(su - $instance_owner -c "export LANG=en_US; db2 list node directory");
  export IFS="
"
  node_name=""
  node_hostname=""
  node_svcename=""
  for line in $list_nodes_output;do
    if echo $line | grep -E "Node [0-9]+ entry:" > /dev/null; then
      if [ ! -z "$node_name" ];then
        if [ "$node_svcename" == "$svcename" -a "$node_hostname" == "127.0.0.1" ];then
          return 0
        fi
      fi
      node_name=""
      node_hostname=""
      node_svcename=""
    elif echo $line | grep -E "Node name[[:space:]]+=" >/dev/null; then
      node_name="${line#*= }"
    elif echo $line | grep -E "Hostname[[:space:]]+=" >/dev/null; then
      node_hostname="${line#*= }"
    elif echo $line | grep -E "Service name[[:space:]]+=" > /dev/null; then
      node_svcename="${line#*= }"
    fi
  done
  unset IFS
  if [ ! -z "$node_name" ];then
    if [ "$node_svcename" == "$svcename" -a "$node_hostname" == "127.0.0.1" ];then
      return 0
    fi
  fi

  #if I got here it means I haven't found local node
  db2_cmd_output=$(su - $instance_owner -c "db2 catalog tcpip node TPC_LBK remote 127.0.0.1 server $svcename")  
  if [ $? -eq 4 ]; then
    echo $db2_cmd_output
    exit 10;
  else
    let directory_entry_ops=$directory_entry_ops+1
    node_name="TPC_LBK"
    return 1  
  fi  
}

function get_tempalias(){
  local -i next=0 # anticipated next 
  local  numb
  local  before_string=""
  local  after_string=""
  local  dbname=""

  for dbname in $dbname_used; do
    numb=${dbname#TPC_}
    numb=${numb#0}
    numb=${numb#0}
    if [ $numb -gt $next ]; then
      tmpstring="00$next"
      tmpstring=${tmpstring:(-3):3}
      TEMPALIAS="TPC_$tmpstring"
      after_string="${dbname_used#$before_string}"
      dbname_used="$before_string $TEMPALIAS $after_string"
      return 0  
    elif [ $numb -eq $next ]; then 
      let next=$next+1
    fi
    before_string="$before_string $dbname"
  done
  tmpstring="00$next"
  tmpstring=${tmpstring:(-3):3}
  TEMPALIAS="TPC_$tmpstring"
  dbname_used="$dbname_used $TEMPALIAS"
  return 0
}

function func_catalog_db_remote(){
  exit_code=0
  for mdm_database in $mdm_databases; do
    if [ ! -z "${!mdm_database}" ]; then
      #if there is defined a variable with the name of a database from MDM.properties, then there is a local database with that alias  
      get_tempalias
      db2_cmd_output=$(su - ${instance_owner} -c "db2 catalog db ${mdm_database} as $TEMPALIAS")
      if [ $? -eq 4 ]; then
        echo $db2_cmd_output
        exit_code=20
        continue;
      fi
      let directory_entry_ops=$directory_entry_ops+1
      db2_cmd_output=$(su - ${instance_owner} -c "db2 uncatalog db ${mdm_database}")  
      if [ $? -eq 4 ]; then
        echo $db2_cmd_output
        exit_code=20
        continue;
      fi
      let directory_entry_ops=$directory_entry_ops+1
      db2_cmd_output=$(su - ${instance_owner} -c "db2 catalog db ${TEMPALIAS} as ${mdm_database} at node ${node_name}")
      if [ $? -eq 4 ]; then
        echo $db2_cmd_output
        exit_code=20
        continue;
      fi
      let directory_entry_ops=$directory_entry_ops+1
    fi
  done
  return $exit_code
}

declare mdm_databases=""
declare node_name=""
declare dbname_used=""
declare -i  directory_entry_ops=0

export USAGE="Usage: \n $0 [--db2_instance <db2_instance>] {--product_name {DM|PM|RM} |  --database <database_1> --database <database_2> ... --database <database_n>}" 

while [ $# -gt 0 ]; do
  case $1 in 
    --database)
      if [ ! -z "$2" ]; then
        tmp_db=$(echo $2 | tr a-z A-Z)
        if [ "${mdm_databases/$tmp_db/}" == "${mdm_databases}" ];then
          mdm_databases="$mdm_databases $tmp_db"
        fi
        shift 2
      else
        echo -e "$USAGE"
        exit 30
      fi  
      ;;
    --db2_instance) 
      if [ ! -z "$2" ]; then
        instance_owner=$2
        shift 2
      else
        echo -e "$USAGE"
        exit 30
      fi 
      ;;
    --product_name)
      if [ ! -z "$2" ]; then
        PROD_NAME=$(echo $2 | tr a-z A-Z)
        shift 2
      else
        echo -e "$USAGE"
        exit 30
      fi 
      ;;
    *)
      echo -e "$USAGE"
      exit 30
      ;;
  esac
done

if [ -z "$PROD_NAME" -a -z "$mdm_databases" ];then
  echo -e "$USAGE"
  exit 30
fi

if [ -z "$instance_owner" ]; then
  instance_owner=db2inst1
fi

db2_cmd_output=$(/opt/IBM/db2/V8.1/instance/db2ilist $instance_owner)
if [ $? -gt  0 ];then
  echo $db2_cmd_output
  exit 35
fi


if [ ! -z "$PROD_NAME" ]; then
  get_mdm_databases
fi

if [  -z "$mdm_databases" ]; then
  exit 36
fi

get_existing_databases
catalog_node
func_catalog_db_remote
last_code=$?

if [ $directory_entry_ops -eq 0 ];then
  exit $last_code 
else
  let last_code=$last_code+1
  exit $last_code
fi

