-- table and data migration from tpc2.1 to tpc.2.3
-- reducing duplicate fields with same information (ESSLSS, getTotalCapacity, getTotalAvailableSpace to be replaced)
update DMEJB.DMSTORAGEPOOL  
set 
TOTALMANAGEDSPACE = TOTALCAPACITY, REMAININGMANAGEDSPACE = TOTALAVAILABLESPACE  
	 where DMPRIMARYKEY in ( (
			select DMPRIMARYKEY from DMEJB.DMSTORAGEPOOL  where 
				( TOTALCAPACITY IS NOT NULL and  TOTALMANAGEDSPACE IS NULL ) or
				(TOTALAVAILABLESPACE IS NOT NULL  and REMAININGMANAGEDSPACE = 0 )));
-- extension of DMReference				
alter table DMEJB.DMReference add column profile VARCHAR(250);	
alter table DMEJB.DMReference add column subprofile VARCHAR(250);
alter table DMEJB.DMReference add column smisversion VARCHAR(250);	
alter table DMEJB.DMReference add column codelevel VARCHAR(250);
alter table DMEJB.DMReference add column manufacturer VARCHAR(250);
alter table DMEJB.DMReference add column model VARCHAR(250);
alter table DMEJB.DMReference add column namespace VARCHAR(250);

update DMEJB.DMREFERENCE A
set
  A.namespace = (select B.namespace from DMEJB.DMCIMOM B
   				  where
                    (A.DMCIMOM_DMPRIMARYKEY = B.DMPRIMARYKEY)
                );
-- DMReference Inventory Collection Flag needs to be set back to false for ESS
update DMEJB.DMReference 
set 
COLLECTIONCOMPLETE = 0
	where TYPE1	like 'DMESS';		

update DMEJB.DMReference 
set 
EXTCOLLECTIONCOMPLETE = 0
	where TYPE1	like 'DMESS';



-- migrate existing FAStT data to provide redundancy info in same 'Redundancy' columns as ESS uses
update DMEJB.DMSTORAGEPOOL  
set 
REDUNDANCY = 'raid0'  
	 where DMSTORAGECONTROLLER_DMPRIMAR16 like 'FAStT%'
	   and CAPELEMENTNAME = 'RAID0';
update DMEJB.DMSTORAGEPOOL  
set 
REDUNDANCY = 'raid1'  
	 where DMSTORAGECONTROLLER_DMPRIMAR16 like 'FAStT%'
	   and CAPELEMENTNAME = 'RAID1';
update DMEJB.DMSTORAGEPOOL  
set 
REDUNDANCY = 'raid3'  
	 where DMSTORAGECONTROLLER_DMPRIMAR16 like 'FAStT%'
	   and CAPELEMENTNAME = 'RAID3';
update DMEJB.DMSTORAGEPOOL  
set 
REDUNDANCY = 'raid5'  
	 where DMSTORAGECONTROLLER_DMPRIMAR16 like 'FAStT%'
	   and CAPELEMENTNAME = 'RAID5';
	   
-- drop DMSERVERINFO table and create DMSERVERINFO table in schema DMEJB, removed since install process takes care of this
-- DROP TABLE DMSERVERINFO;

CREATE TABLE DMEJB.DMSERVERINFO
  (HOSTNAME VARCHAR(100) NOT NULL,
   USERID VARCHAR(100) NOT NULL,
   PASSWORD VARCHAR(100) FOR BIT DATA NOT NULL);

-- create and fill Dmphysicalpackage_Dmstoragepool mapping table to allow for m:n mappings between ESSLSS and PhysicalPackage
CREATE TABLE DMEJB.Dmphysicalpackage_Dmstoragepool 
  (DMPHYSICALPACKAGE_DMPRIMARYKEY VARCHAR(250) NOT NULL, 
   DMSTORAGEPOOL_DMPRIMARYKEY VARCHAR(250) NOT NULL);
ALTER TABLE DMEJB.Dmphysicalpackage_Dmstoragepool 
  ADD CONSTRAINT PK_Dmphysicalpack1 PRIMARY KEY (DMPHYSICALPACKAGE_DMPRIMARYKEY, DMSTORAGEPOOL_DMPRIMARYKEY);
EXPORT TO '{4}' OF IXF 
  select DMPHYSICALPACK_PK, DMPRIMARYKEY  from DMEJB.DMSTORAGEPOOL 
  where DMPHYSICALPACK_PK is not null;
IMPORT FROM '{4}' OF IXF 
  insert into DMEJB.Dmphysicalpackage_Dmstoragepool;

-- add columns to support ITMS
alter table DMEJB.DMVOLUME 
  add column VOLNUMBER INTEGER;
  
-- Comment out by Tony on 03/17; anyway the table DMEJB.DMSTORAGEPOOL is to be dropped and recreated with this new column.

-- fill column to support ITMS (column lss in DMEJB.DMSTORAGEPOOL cannot be filled, new inventory collection required
update DMEJB.DMVOLUME 
  set volnumber = int(16*((ascii(lcase(substr(name,length(name)-1,1)))-87)*(1+sign(ascii(lcase(substr(name,length(name)-1,1)))-87))*0.5+(1+sign(58-ascii(lcase(substr(name,length(name)-1,1)))))*0.5*(10-(58-ascii(lcase(substr(name,length(name)-1,1))))))+(ascii(lcase(substr(name,length(name),1)))-87)*(1+sign(ascii(lcase(substr(name,length(name),1)))-87))*0.5+(1+sign(58-ascii(lcase(substr(name,length(name),1)))))*0.5*(10-(58-ascii(lcase(substr(name,length(name),1)))))) 
  where  DMPRIMARYKEY like '2105%' or DMPRIMARYKEY like '2107%' or DMPRIMARYKEY like '1750%';

-- add column BASEDON for ESS and DSx000S, add column does not work since table now exceeds 4K page, needs to be recreated in a 8K table space
-- alter table DMEJB.DMSTORAGEPOOL add column BASEDON VARCHAR(250);
EXPORT TO '{5}' OF IXF 
  select *  from DMEJB.DMSTORAGEPOOL;
DROP TABLE DMEJB.DMSTORAGEPOOL;
-- Comment by Tony on 03/17; copied create statement from DMTAbles.ddl
CREATE TABLE DMEJB.DMSTORAGEPOOL
  (DMPRIMARYKEY VARCHAR(250) NOT NULL,
   TOTALMANAGEDSPACE BIGINT,
   POOLID VARCHAR(250),
   PRIMORDIAL SMALLINT,
   REMAININGMANAGEDSPACE BIGINT,
   STATUS VARCHAR(250),
   ELEMENTNAME VARCHAR(250),
   DMSTORAGECONTROLLER_DMPRIMAR16 VARCHAR(250),
   DMSSI_DMPRIMARYKEY VARCHAR(250),
   DMESS_DMPRIMARYKEY VARCHAR(250),
   CAPACITY REAL,
   FREE1 REAL,
   ID VARCHAR(250),
   VOLUMES1 INTEGER,
   REDUNDANCY VARCHAR(250),
   EXTENTSIZE INTEGER,
   NAME VARCHAR(250),
   NATIVESTATUS INTEGER,
   NUMBEROFBACKENDVOLUMES INTEGER,
   NUMBEROFSTORAGEVOLUMES INTEGER,
   TOTALAVAILABLESPACE BIGINT,
   TOTALCAPACITY BIGINT,
   INSTANCEID VARCHAR(250),
   DATAREDUNDANCYMIN INTEGER,
   DATAREDUNDANCYMAX INTEGER,
   DATAREDUNDANCYDEF INTEGER,
   PACKREDUNDANCYMIN INTEGER,
   PACKREDUNDANCYMAX INTEGER,
   PACKREDUNDANCYDEF INTEGER,
   DELTARESMIN INTEGER,
   DELTARESMAX INTEGER,
   DELTARESDEF INTEGER,
   ELEMENTTYPE INTEGER,
   CAPELEMENTNAME VARCHAR(250),
   DMPHYSICALPACK_PK VARCHAR(250),
   RANKID VARCHAR(250),
   LSS VARCHAR(250),
   BASEDON VARCHAR(250),
   STORAGETYPE VARCHAR(250));

ALTER TABLE DMEJB.DMSTORAGEPOOL
  ADD CONSTRAINT PK_DMSTORAGEPOOL PRIMARY KEY (DMPRIMARYKEY);
IMPORT FROM '{5}' OF IXF 
  insert into DMEJB.DMSTORAGEPOOL;
  
UPDATE DMEJB.DMSTORAGEPOOL 
   SET  CAPACITY = 1E9*CAPACITY 
WHERE CAPACITY IS NOT NULL;  
 
UPDATE DMEJB.DMSTORAGEPOOL 
   SET  FREE1 = 1E9*FREE1 
WHERE FREE1 IS NOT NULL;   

-- @16421 for DS8k/6k 
alter table DMEJB.DMSTORAGECONTROLLER add column MTMS VARCHAR(100);	


